@@ -12,7 +12,6 @@ import argparse
 import logging
 import socket
 
-import glob
 import shutil
 
 from client import worker
@@ -44,6 +43,7 @@ def arg_parser():
                         client instances on a machine)",
         required=False,
         type=str,
+        default=""
     )
     parser.add_argument(
         "-t",
@@ -69,6 +69,13 @@ def arg_parser():
         help="increase output verbosity",
         action="store_true",
     )
+    parser.add_argument(
+        "-a",
+        "--autostart",
+        required=False,
+        help="set the number of threads to be automatically activated",
+        default="0",
+    )
     return parser.parse_args()
 
 
@@ -105,8 +112,8 @@ if __name__ == "__main__":
                           ARGS.threads)
             sys.exit(1)
         NB_PROCESS = ARGS.threads
-    if ARGS.suffix:
-        HOSTNAME += ARGS.suffix
+
+    HOSTNAME += ARGS.suffix
 
     logging.info("HOSTNAME : %s", HOSTNAME)
     logging.info("NB_PROCESS : %s", NB_PROCESS)
@@ -115,10 +122,11 @@ if __name__ == "__main__":
         logging.info("Appel de la fonction nettoyage")
         logging.info("  Suppression des répertoires temporaires")
 
+        folder_to_remove = worker.list_tmp_folder(ARGS.suffix)
         logging.info("  Nombre de répertoire à supprimer : %s",
-                     len(glob.glob('tmp*')))
+                     len(worker.list_tmp_folder(ARGS.suffix)))
 
-        for file in glob.glob('tmp*'):
+        for file in folder_to_remove:
             shutil.rmtree(file)
 
         logging.info("  Suppression des sessions obsolètes")
@@ -150,12 +158,15 @@ if __name__ == "__main__":
                       "pour purger les sessions non fermées")
         sys.exit(1)
 
-    worker.exec_multiprocess(
-        worker.URL_API,
-        HOSTNAME,
-        NB_PROCESS,
-        ARGS.tags,
-        False
-    )
+    parameters = {
+        'url_api': worker.URL_API,
+        'hostname': HOSTNAME,
+        'tags': ARGS.tags,
+        'autostart': ARGS.autostart,
+        'mode_exec_and_quit': False,
+        'suffix': ARGS.suffix
+    }
+
+    worker.exec_multiprocess(NB_PROCESS, parameters)
 
     logging.info("Fin du client GPAO")
