@@ -14,9 +14,8 @@ import os
 import logging
 import signal
 import multiprocessing
-
 from functools import partial
-
+import re
 import requests
 
 # espace libre minimal en Go sur un dossier de travail pour accepter un job
@@ -33,6 +32,13 @@ URL_API = (
     + "/api/"
 )
 
+
+def list_tmp_folder(suffix: str):
+    """List tmp folder on the disk. Parameter suffix can be empty string, or any suffix."""
+    regex = "tmp" + suffix + ".{8}$"
+    return [f for f in os.listdir('.') if re.match(regex, f)]
+
+
 def build_url_api(hostname: str, port="8080"):
     """construit l'url"""
     return f"http://{hostname}:{port}/api/"
@@ -40,22 +46,21 @@ def build_url_api(hostname: str, port="8080"):
 
 def send_request(url, mode, json=None, str_thread_id=None):
     """ Fonction executant les requetes http """
-    success = False
     logging.debug("%s : %s : %s", str_thread_id, mode, url)
-    while not success:
+    while True:
         try:
+            req = ""
             if mode == "GET":
                 req = requests.get(url, timeout=60)
                 req.raise_for_status()
-                return req
             if mode == "PUT":
                 req = requests.put(url, timeout=60)
                 req.raise_for_status()
-                return req
             if mode == "POST":
                 req = requests.post(url, json=json, timeout=60)
                 req.raise_for_status()
-                return req
+            return req
+
         except requests.exceptions.Timeout:
             logging.error("%s : timeout sur l'url : %s", str_thread_id, url)
             time.sleep(1)
@@ -67,6 +72,7 @@ def send_request(url, mode, json=None, str_thread_id=None):
                           str_thread_id, url)
             logging.error("%s : Erreur %s", str_thread_id, exception)
             time.sleep(1)
+    return None
 
 
 def get_free_space_gb(dirname):
@@ -206,6 +212,15 @@ def is_enought_free_space_on_disk(working_dir):
     return True
 
 
+def custom_sleep(mode_test: bool):
+    """ Pause, plus courte pour les tests """
+    if mode_test:
+        # test should be fast
+        time.sleep(random.randrange(2, 5))
+    else:
+        time.sleep(random.randrange(20, 30))
+
+
 def process(parameters, id_thread):
     """ Traitement pour un thread """
     url_api = parameters["url_api"]
@@ -215,11 +230,14 @@ def process(parameters, id_thread):
     # pour que les commandes systemes soient reconnues
     shell = platform.system() == "Windows"
 
+    try_before_exiting = 2
     try:
         # On cree un dossier temporaire dans le dossier
         # courant qui devient le dossier d'execution
-        with tempfile.TemporaryDirectory(dir=".") as working_dir:
+        with tempfile.TemporaryDirectory(dir=".",
+                                         prefix="tmp" + parameters["suffix"]) as working_dir:
 
+            # insertion de la session dans la base
             url = "session?host=" + parameters["hostname"]
             if parameters["tags"]:
                 url += "&tags=" + parameters["tags"]
@@ -232,21 +250,22 @@ def process(parameters, id_thread):
             logging.info("%s : working dir (%s) id_session (%s)",
                          str_thread_id, working_dir, id_session)
 
-            if parameters["mode_exec_and_quit"]:
-                logging.info("%s : Ce thread devient actif", str_thread_id)
+            if int(parameters["autostart"]) > 0:
+                logging.debug("%s : Ce thread devient actif", str_thread_id)
                 host = parameters["hostname"]
 
-                send_request(url_api + "node/setNbActive?host="
-                             + host + "&limit=10",
+                send_request(url_api + "node/setNbActive?value=" +
+                             parameters["autostart"],
                              "POST",
+                             json={"hosts": [host]},
                              str_thread_id=str_thread_id)
 
             while True:
                 # on verifie l'espace disponible dans le dossier de travail
                 req = None
                 if is_enought_free_space_on_disk(working_dir):
-                    url_tmp = "job/ready?id_session=" + str(id_session)
-                    req = send_request(url_api + url_tmp,
+                    url = "job/ready?id_session=" + str(id_session)
+                    req = send_request(url_api + url,
                                        "GET",
                                        str_thread_id=str_thread_id)
                 if req and req.json():
@@ -270,11 +289,11 @@ def process(parameters, id_thread):
                                  status,
                                  error_message)
 
-                    url_tmp = ("job?id=" + str(id_job) +
+                    url = ("job?id=" + str(id_job) +
                                "&status=" + str(status) +
                                "&returnCode=" + str(return_code))
 
-                    req = send_request(url_api + url_tmp,
+                    req = send_request(url_api + url,
                                        "POST",
                                        json={"log": error_message},
                                        str_thread_id=str_thread_id)
@@ -286,14 +305,14 @@ def process(parameters, id_thread):
                                       req.content)
                 else:
                     if parameters["mode_exec_and_quit"]:
-                        logging.info("%s : Mode test, et plus de "
-                                     "job à faire => sortie",
-                                     str_thread_id)
-                        raise KeyboardInterrupt
+                        if try_before_exiting <= 0:
+                            logging.info("%s : Mode test, et plus de "
+                                        "job à faire => sortie",
+                                        str_thread_id)
+                            raise KeyboardInterrupt
+                        try_before_exiting = try_before_exiting - 1
 
-                    # sleep
-                    if not parameters["mode_exec_and_quit"]:
-                        time.sleep(random.randrange(20, 30))
+                    custom_sleep(parameters["mode_exec_and_quit"])
 
     except KeyboardInterrupt:
         logging.info("%s : On demande au process de s'arreter", str_thread_id)
@@ -305,8 +324,17 @@ def process(parameters, id_thread):
     logging.info("%s : Fin du thread", str_thread_id)
 
 
-def exec_multiprocess(url_api, hostname, nb_process, tags, mode_exec_and_quit):
-    """ Execution du multiprocess """
+def exec_multiprocess(nb_process, parameters):
+    """ Execution du multiprocess. parameter is a dict containing:
+        parameters = {
+        'url_api': str,
+        'hostname': str,
+        'tags': "tags separated by ,",
+        'autostart': "Number of threads active, as string",
+        'mode_exec_and_quit': True or False,
+        'suffix': empty string or any suffix
+    }
+    """
     if platform.system() == "Windows":
         if nb_process > 60:
             logging.info("Limite Windows: 60 threads au lieu des %s demandés",
@@ -316,11 +344,6 @@ def exec_multiprocess(url_api, hostname, nb_process, tags, mode_exec_and_quit):
     with multiprocessing.Pool(nb_process) as pool:
         signal.signal(signal.SIGINT, signal.SIG_IGN)
 
-        parameters = {'url_api': url_api,
-                      'hostname': hostname,
-                      'tags': tags,
-                      'mode_exec_and_quit': mode_exec_and_quit}
-
         func_process = partial(process, parameters)
 
         try:
